@@ -78,11 +78,13 @@ class User:
         return super(User, cls).create(vlist)
 
     @classmethod
-    def write(cls, users, values):
-        if values.get('password'):
-            logins = [x.login for x in users]
-            cls._check_passwd_ldap_user(logins)
-        super(User, cls).write(users, values)
+    def write(cls, *args):
+        actions = iter(args)
+        for users, values in zip(actions, actions):
+            if values.get('password'):
+                logins = [x.login for x in users]
+                cls._check_passwd_ldap_user(logins)
+        super(User, cls).write(*args)
 
     @classmethod
     def set_preferences(cls, values, old_password=False):
@@ -119,18 +121,17 @@ class User:
         with Transaction().set_user(0):
             connection, = Connection.search([], limit=1)
         try:
-            con = ldap.initialize(connection.uri or '')
+            con = ldap.initialize(connection.uri)
             if connection.active_directory:
                 con.set_option(ldap.OPT_REFERRALS, 0)
             if connection.secure == 'tls':
                 con.start_tls_s()
             if connection.bind_dn:
-                con.simple_bind_s(connection.bind_dn or '',
-                    connection.bind_pass or '')
+                con.simple_bind_s(connection.bind_dn, connection.bind_pass)
             [(dn, attrs)] = cls.ldap_search_user(login, con, connection,
                 attrs=[str(connection.auth_uid)])
             if password and con.simple_bind_s(dn, password):
-                user_id, _, _ = cls._get_login(login)
+                user_id, _ = cls._get_login(login)
                 if user_id:
                     LoginAttempt.remove(login)
                     return user_id
